ChartAxis class

Represents an axis on the chart.

Implementers

Constructors

ChartAxis()

Properties

hasAxisTitle → bool
Gets indicates whether chart axis have title or not.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasMajorGridLines ↔ bool
Gets or sets a boolean value indicating if the axis has major grid lines.
getter/setter pair
isAutoMax → bool
Gets indicates whether auto max or not.
no setter
isAutoMin → bool
no setter
maximumValue ↔ double
Represents maximumvalue of Axis.
getter/setter pair
minimumValue ↔ double
Represents minimumvalue of Axis.
getter/setter pair
numberFormat ↔ String
Represents number format.
getter/setter pair
parentChart ↔ Chart
Gets the parent chart.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Gets chart axis title.
getter/setter pair
titleArea ↔ ChartTextArea
Gets chart text area object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited