ChartCollection class

Represents the worksheet rows.

Constructors

ChartCollection(Worksheet worksheet)
Create a instance of ChartCollection class.

Properties

count → int
Returns the count of chart collection.
no setter
hashCode → int
The hash code for this object.
no setterinherited
innerList → List<Chart>
Represents the innerlist
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worksheet → Worksheet
Represents parent worksheet.
no setter

Methods

add() → Chart
Add chart to the chart collection.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serializeChartDrawing(XmlBuilder builder, Worksheet sheet) → Future<void>
Serialize the chart drawings.
serializeChartDrawingSync(XmlBuilder builder, Worksheet sheet) → void
Serialize the chart drawings.
serializeCharts(Worksheet sheet) → Future<void>
Serialize the charts.
serializeChartsSync(Worksheet sheet) → void
Serialize the charts.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic index) → Chart
Indexer of the class