ChartDataLabels class

Represents the Chart data labels class.

Constructors

ChartDataLabels(ChartSerie serie)
Create an instances of ChartDataLabels class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
isCategoryName ↔ bool
Gets or sets a boolean value indicating whether to display category name for data labels.
getter/setter pair
isSeriesName ↔ bool
Gets or sets a boolean value indicating whether to display series name for data labels.
getter/setter pair
isValue ↔ bool
Gets or sets a boolean value indicating whether to display data label values.
getter/setter pair
numberFormat ↔ String?
Represents number format.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textArea ↔ ChartTextArea
Gets chart text area object.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited