ChartLegend class

Represents an legend on the chart.

Constructors

ChartLegend(Worksheet worksheet, Chart chart)
Create an instances of ChartLegend class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
hasTextArea → bool
Gets the chart legend have text area or not.
no setter
position ↔ ExcelLegendPosition
Gets and sets the chart legend position.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textArea → ChartTextArea
Gets the chart legend text area.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited