ChartPlotArea class

Represents chart plot area object.

Constructors

ChartPlotArea(Worksheet worksheet, Chart chart)
Create an instances of ChartPlotArea class.

Properties

hashCode → int
The hash code for this object.
no setterinherited
linePattern ↔ ExcelChartLinePattern
Represent PlotArea border line property
getter/setter pair
linePatternColor ↔ String?
ChartArea border line color property
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited