ChartSerie class

This class represents ChartSeries object.

Constructors

ChartSerie(Worksheet worksheet, Chart chart)
Create an instances of ChartSerie class.

Properties

categoryLabels ↔ Range?
Set the chart range values
getter/setter pair
chart ↔ Chart
Sets the parent chart
getter/setter pair
dataLabels → ChartDataLabels
Gets chart text area object.
no setter
hashCode → int
The hash code for this object.
no setterinherited
index ↔ int
getter/setter pair
isDefaultName ↔ bool
getter/setter pair
linePattern ↔ ExcelChartLinePattern
Represents the PlotArea border line property
getter/setter pair
linePatternColor ↔ String?
ChartArea border line color property
getter/setter pair
name ↔ String?
Represent the serie name.
getter/setter pair
nameOrFormula ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
serieFormat → ChartSerieDataFormat
Represents chart serie format.
no setter
serieType → ExcelChartType
Chart type for the series.
no setter
values ↔ Range?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited