ChartSeriesCollection class

Represents the Chart serie collection.

Constructors

ChartSeriesCollection(Worksheet worksheet, Chart chart)
Create a instance of ChartSeriesCollection class.

Properties

count → int
Returns the count of pivot reference collection.
no setter
hashCode → int
The hash code for this object.
no setterinherited
innerList → List<ChartSerie>
Represents the innerList.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
worksheet → Worksheet
Represents parent worksheet.
no setter

Methods

add() → ChartSerie
Add serie to the chart serie collection.
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](dynamic index) → ChartSerie
Indexer of the class