ChartTextArea class

Represent the Chart Text Area.

Constructors

ChartTextArea(Object parent)
Create an instances of ChartTextArea class.

Properties

bold ↔ bool
Gets bold.
getter/setter pair
color ↔ String
Represent the color.
getter/setter pair
fontName ↔ String
Gets font name.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasText → bool
no setter
italic ↔ bool
Gets italic.
getter/setter pair
overlay → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ double
Gets font size.
getter/setter pair
text ↔ String?
Represent the title name.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited