ChartValueAxis class

Represents an axis on the chart.

Inheritance

Constructors

ChartValueAxis(Worksheet worksheet, Chart chart)
Create an instances of ChartValueAxis class.

Properties

chart → Chart
no setter
hasAxisTitle → bool
Gets indicates whether chart axis have title or not.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
hasMajorGridLines ↔ bool
Gets or sets a boolean value indicating if the axis has major grid lines.
getter/setter pairinherited
isAutoMax → bool
Gets indicates whether auto max or not.
no setterinherited
isAutoMin → bool
no setterinherited
maximumValue ↔ double
Represents maximumvalue of Axis.
getter/setter pairinherited
minimumValue ↔ double
Represents minimumvalue of Axis.
getter/setter pairinherited
numberFormat ↔ String
Represents number format.
getter/setter pairinherited
parentChart ↔ Chart
Gets the parent chart.
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title ↔ String?
Gets chart axis title.
getter/setter pairinherited
titleArea ↔ ChartTextArea
Gets chart text area object.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited